akhdefo_functions.akhdefo_viewer — Akhdefo software documentation

# akhdefo_functions.akhdefo_viewer

akhdefo_functions.akhdefo_viewer(Path_to_DEMFile='', rasterfile='', cbar_label='Velocity(mm/year)', title='Akhdefo-Viewer', pixel_resolution_meter=3.125, outputfolder='', alpha=0.8, unit=1, cmap='jet', noDATA_Mask=False, Normalize=True, SetDates_Filename=False, Set_fig_MinMax=False)

  This program used for plotting raster products.

  ## Parameters

  Path_to_DEMFilestr

    provide path to digital elevation raster file to be used as shaded base Map

  rasterfilestr

    provide path to raster file to be plotted

  titlestr

    provide your desired title for the plot

  pixel_resolution_meterfloat

    provide pixel resolution of the digital elevation raster to draw proper figure scalebar

  outputfolderstr

    provide path to ouput folder to save the plot

  outputfileNamestr

    provide name for the output plot including the desired extension such as .jpg, .pmg, .pdf, etc..

  alphafloat

    transparency level for the plotted raster relative to hillshaded basemap

  unitint

    conversion unit default is 1 (no conversion) if your data is in meter such as velocity in meter/year set unit to 2 to convert to mm/year

  noDATA_MAskbool

    set to True if you do not want to plot zero values of your dataset

  ## Returns

  Figure